package com.kfb.kfbv1.model;

import java.util.ArrayList;

public class KfbGate {
    private int Id;
    private String mName;
    private String mAdres;
    private String mMaxT;
    private String mStatus;
    private String mStat;
    private String mError;
    private boolean mNoPing;
    private boolean mActive;
    private KfbMeasure mMeasure;
    public int StanTab;
    public String getmStat() {
        return mStat;
    }

    public void setmStat(String mStat) {
        this.mStat = mStat;
    }

    public boolean ismNoPing() {
        return mNoPing;
    }

    public void setmNoPing(boolean mNoPing) {
        this.mNoPing = mNoPing;
    }

    public boolean ismActive() {
        return mActive;
    }

    public int getId() {
        return Id;
    }

    public void setId(int id) {
        Id = id;
    }

    public void setmActive(boolean mActive) {
        this.mActive = mActive;
    }

    public void setmName(String mName) {
        this.mName = mName;
    }

    public void setmAdres(String mAdres) {
        this.mAdres = mAdres;
    }

    public String getmAdres() {
        return mAdres;
    }

    public void setmMeasure(KfbMeasure mMeasure) {
        this.mMeasure = mMeasure;
    }

    public String getmName() {
        return mName;
    }

    public KfbMeasure getmMeasure() {
        return mMeasure;
    }

    public KfbGate()
    {
        mMeasure = new KfbMeasure();
        mNoPing = true;
        mStatus ="";
        StanTab = 0;
    }

    public void setmMaxT(String mMaxT) {
        this.mMaxT = mMaxT;
    }

    public String getmError() {
        return mError;
    }

    public void setmError(String mError) {
        this.mError = mError;
    }

    public void setmStatus(String mStatus) {
        this.mStatus = mStatus;
    }

    public String getmMaxT() {
        return mMaxT;
    }

    public String getmStatus() {
        return mStatus;
    }
}
